@@ -1,7 +1,7 @@
 package Sah::Schema::Rinci;
 
 our $DATE = '2015-02-07'; # DATE
-our $VERSION = '1.1.72'; # VERSION
+our $VERSION = '1.1.73'; # VERSION
 
 use 5.010001;
 use strict;
@@ -85,9 +85,24 @@ $SCHEMAS{rinci_function} = [hash => {
                 cmdline_src => {},
                 meta => 'fix',
                 element_meta => 'fix',
+                deps => {
+                    _keys => {
+                        arg => {},
+                        all => {},
+                        any => {},
+                        none => {},
+                    },
+                },
             },
         },
         args_as => {},
+        args_groups => {
+            _elem_prop => {
+                %dh_props,
+                args => {},
+                rel => {},
+            },
+        },
         result => {
             _prop => {
                 %dh_props,
@@ -191,7 +206,7 @@ Sah::Schema::Rinci - Sah schemas for Rinci metadata
 
 =head1 VERSION
 
-This document describes version 1.1.72 of Sah::Schema::Rinci (from Perl distribution Rinci), released on 2015-02-07.
+This document describes version 1.1.73 of Sah::Schema::Rinci (from Perl distribution Rinci), released on 2015-02-07.
 
 =head1 HOMEPAGE
 
